@@ -160,8 +160,9 @@ def save_img(vol,
     if terminal:
         if lattice.decon_processing:
             decon_value = True
-            decon_option = lattice.decon_processing
+            decon_option = lattice.decon_processing #decon_processing holds the choice
             lattice_class = lattice
+            
     else:
         decon_value = LLSZWidget.LlszMenu.deconvolution.value
         lattice_class = LLSZWidget.LlszMenu.lattice
@@ -189,26 +190,35 @@ def save_img(vol,
             image_type = raw_vol.dtype
 
             #If deconvolution is checked
-            if decon_value:
+            if decon_value and func != crop_volume_deskew:
                 #Use CUDA or skimage for deconvolution based on user choice
                 if decon_option =="cuda_gpu":
                     print("cuda")
                     raw_vol = pycuda_decon(image = raw_vol, 
                                            #otf_path = LLSZWidget.LlszMenu.lattice.otf_path[ch],
-                                           psf = LLSZWidget.LlszMenu.lattice.psf[ch],
-                                           dzdata=LLSZWidget.LlszMenu.lattice.dz,
-                                           dxdata=LLSZWidget.LlszMenu.lattice.dx,
-                                           dzpsf=LLSZWidget.LlszMenu.lattice.dz,
-                                           dxpsf=LLSZWidget.LlszMenu.lattice.dx)
+                                           psf = lattice_class.psf[ch],
+                                           dzdata=lattice_class.dz,
+                                           dxdata=lattice_class.dx,
+                                           dzpsf=lattice_class.dz,
+                                           dxpsf=lattice_class.dx,
+                                           num_iter=lattice_class.psf_num_iter)
                 else:
                     raw_vol = skimage_decon(vol_zyx=raw_vol, 
-                                            psf=LLSZWidget.LlszMenu.lattice.psf[ch], 
-                                            num_iter=10, clip=False, filter_epsilon=0, boundary='nearest')
-      
+                                            psf=lattice_class.psf[ch], 
+                                            num_iter=lattice_class.psf_num_iter,
+                                            clip=False, filter_epsilon=0, boundary='nearest')
+            
 
             #The following will apply the user-passed function to the input image
             if func is cle.deskew_y:
                 processed_vol = func(input_image = raw_vol, *args,**kwargs).astype(image_type)
+            elif func is crop_volume_deskew and decon_value==True:
+                processed_vol = func(original_volume = raw_vol,
+                                     deconvolution=decon_value,
+                                     decon_processing = decon_option,
+                                     psf=lattice_class.psf[ch],
+                                     num_iter=lattice_class.psf_num_iter,
+                                     *args,**kwargs).astype(image_type)
             elif func is crop_volume_deskew:
                 processed_vol = func(original_volume = raw_vol, *args,**kwargs).astype(image_type)
             else:
